==> zio-aws-timestreamquery_3-5.17.151.2-sources.jar: zio/aws/timestreamquery/model/TimestreamDestination.scala <==
package zio.aws.timestreamquery.model
import zio.ZIO
import zio.aws.timestreamquery.model.primitives.ResourceName
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class TimestreamDestination(
    databaseName: Option[ResourceName] = None,
    tableName: Option[ResourceName] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.timestreamquery.model.TimestreamDestination = {
    import TimestreamDestination.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.timestreamquery.model.TimestreamDestination
      .builder()
      .optionallyWith(
        databaseName.map(value => ResourceName.unwrap(value): java.lang.String)
      )(_.databaseName)
      .optionallyWith(
        tableName.map(value => ResourceName.unwrap(value): java.lang.String)
      )(_.tableName)
      .build()
  }
  def asReadOnly: zio.aws.timestreamquery.model.TimestreamDestination.ReadOnly =
    zio.aws.timestreamquery.model.TimestreamDestination.wrap(buildAwsValue())
}
object TimestreamDestination {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.timestreamquery.model.TimestreamDestination
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.timestreamquery.model.TimestreamDestination =
      zio.aws.timestreamquery.model.TimestreamDestination(
        databaseName.map(value => value),
        tableName.map(value => value)
      )
    def databaseName: Option[ResourceName]
    def tableName: Option[ResourceName]
    def getDatabaseName: ZIO[Any, AwsError, ResourceName] =
      AwsError.unwrapOptionField("databaseName", databaseName)
    def getTableName: ZIO[Any, AwsError, ResourceName] =
      AwsError.unwrapOptionField("tableName", tableName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.timestreamquery.model.TimestreamDestination
  ) extends zio.aws.timestreamquery.model.TimestreamDestination.ReadOnly {
    override val databaseName: Option[ResourceName] = scala
      .Option(impl.databaseName())
      .map(value =>
        zio.aws.timestreamquery.model.primitives.ResourceName(value)
      )
    override val tableName: Option[ResourceName] = scala
      .Option(impl.tableName())
      .map(value =>
        zio.aws.timestreamquery.model.primitives.ResourceName(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.timestreamquery.model.TimestreamDestination
  ): zio.aws.timestreamquery.model.TimestreamDestination.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-timestreamquery_3-5.17.295.13-sources.jar: zio/aws/timestreamquery/model/TimestreamDestination.scala <==
package zio.aws.timestreamquery.model
import zio.ZIO
import zio.aws.timestreamquery.model.primitives.ResourceName
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class TimestreamDestination(
    databaseName: Optional[ResourceName] = Optional.Absent,
    tableName: Optional[ResourceName] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.timestreamquery.model.TimestreamDestination = {
    import TimestreamDestination.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.timestreamquery.model.TimestreamDestination
      .builder()
      .optionallyWith(
        databaseName.map(value => ResourceName.unwrap(value): java.lang.String)
      )(_.databaseName)
      .optionallyWith(
        tableName.map(value => ResourceName.unwrap(value): java.lang.String)
      )(_.tableName)
      .build()
  }
  def asReadOnly: zio.aws.timestreamquery.model.TimestreamDestination.ReadOnly =
    zio.aws.timestreamquery.model.TimestreamDestination.wrap(buildAwsValue())
}
object TimestreamDestination {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.timestreamquery.model.TimestreamDestination
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.timestreamquery.model.TimestreamDestination =
      zio.aws.timestreamquery.model.TimestreamDestination(
        databaseName.map(value => value),
        tableName.map(value => value)
      )
    def databaseName: Optional[ResourceName]
    def tableName: Optional[ResourceName]
    def getDatabaseName: ZIO[Any, AwsError, ResourceName] =
      AwsError.unwrapOptionField("databaseName", databaseName)
    def getTableName: ZIO[Any, AwsError, ResourceName] =
      AwsError.unwrapOptionField("tableName", tableName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.timestreamquery.model.TimestreamDestination
  ) extends zio.aws.timestreamquery.model.TimestreamDestination.ReadOnly {
    override val databaseName: Optional[ResourceName] = zio.aws.core.internal
      .optionalFromNullable(impl.databaseName())
      .map(value =>
        zio.aws.timestreamquery.model.primitives.ResourceName(value)
      )
    override val tableName: Optional[ResourceName] = zio.aws.core.internal
      .optionalFromNullable(impl.tableName())
      .map(value =>
        zio.aws.timestreamquery.model.primitives.ResourceName(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.timestreamquery.model.TimestreamDestination
  ): zio.aws.timestreamquery.model.TimestreamDestination.ReadOnly = new Wrapper(
    impl
  )
}
